CommandLineUsageException class

Exception thrown when arguments are incorrect.

Inheritance
Implemented types

Constructors

CommandLineUsageException({String message = '', String argumentName = '', String argumentValue = ''})

Properties

argumentName → String
final
argumentValue → String
final
exitCode → int
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited